@@ -4,7 +4,7 @@ function (formula, data, subset, na.action = NULL, y = NULL, Xext = NULL, selec
           simplify = TRUE, ref = 1, ref.no = NA, fact.ratio = 1, ref.y = 1, p.corrected = TRUE, compute.ratio = TRUE, 
           include.miss = FALSE, oddsratio.method = "midp", chisq.test.perm = FALSE, byrow = FALSE, chisq.test.B = 2000, 
           chisq.test.seed = NULL, Date.format = "d-mon-Y", var.equal = TRUE, conf.level = 0.95, surv=FALSE,
-          riskratio = FALSE, riskratio.method = "wald", compute.prop = FALSE) 
+          riskratio = FALSE, riskratio.method = "wald", compute.prop = FALSE, lab.missing = "'Missing'") 
 {
     tibble <- FALSE
     if (missing(formula)) 
@@ -26,7 +26,7 @@ function (formula, data, subset, na.action = NULL, y = NULL, Xext = NULL, selec
         }
       }
     }
-    
+
     call <- match.call()
     if (missing(data))
         data <- environment(formula)
@@ -39,7 +39,7 @@ function (formula, data, subset, na.action = NULL, y = NULL, Xext = NULL, selec
         vl <- sapply(data, attr, which="labels", exact=TRUE) # store value.labels
       }
     }
-    
+
     # remove labelled class (for incompatibility with haven and Hmisc)
     for (i in 1:ncol(data)){
       if (inherits(data[,i],"labelled"))
@@ -67,14 +67,14 @@ function (formula, data, subset, na.action = NULL, y = NULL, Xext = NULL, selec
       }
     }
 
-    if (is.null(frame.call$drop.unused.levels)) 
-      frame.call$drop.unused.levels <- TRUE
+    #if (is.null(frame.call$drop.unused.levels)) 
+    frame.call$drop.unused.levels <- simplify #TRUE
     if (is.null(frame.call$na.action)) 
       frame.call$na.action = na.pass
     frame.call[["data"]] <- data # in data, non standard characters in names are replaced by . (tibbles)
 
     m <- eval(frame.call, sys.parent())
-    
+
     if (is.environment(data))
       data <- m
     
@@ -149,7 +149,8 @@ function (formula, data, subset, na.action = NULL, y = NULL, Xext = NULL, selec
                   fact.ratio = fact.ratio, ref.y = ref.y, p.corrected = p.corrected, compute.ratio = compute.ratio, 
                   include.miss = include.miss, oddsratio.method = oddsratio.method, chisq.test.perm = chisq.test.perm, byrow = byrow, 
                   chisq.test.B = chisq.test.B, chisq.test.seed = chisq.test.seed, Date.format = Date.format, var.equal=var.equal, 
-                  conf.level=conf.level,surv=surv,riskratio=riskratio,riskratio.method=riskratio.method,compute.prop=compute.prop)"), collapse="")
+                  conf.level=conf.level,surv=surv,riskratio=riskratio,riskratio.method=riskratio.method,compute.prop=compute.prop,
+                  lab.missing=lab.missing)"), collapse="")
 
     ans <- eval(parse(text=cmd))
     
