@@ -8,12 +8,16 @@ confinterval <- function(x, method, conf.level){
     upp <- m - qt(alpha/2, n - 1) * se
     return(c('Mean' = m, 'lower' = low, 'upper' = upp))
   } else {
-    if (qbinom(alpha/2, n, 0.5) == 0) 
-      stop("cannot compute CI")
+    if (qbinom(alpha/2, n, 0.5) == 0){ 
+      warning("cannot compute CI")
+      return(c('Mean' = NA, 'lower' = NA, 'upper' = NA))
+    }
     L <- qbinom(alpha/2, n, 0.5)
     U <- n - L + 1
-    if (L >= U) 
-      stop("cannot compute CI")
+    if (L >= U) {
+      warning("cannot compute CI")
+      return(c('Mean' = NA, 'lower' = NA, 'upper' = NA))      
+    }
     order.x <- sort(x)
     c('Median' = median(x), 'lower' = order.x[L], 'upper' = order.x[n - L + 1])
   }
